package benefactorkindboxreqhandler

import (
	"net/http"

	param "git.gocasts.ir/ebhomengo/niki/param/benefactor/kind_box_req"
	"git.gocasts.ir/ebhomengo/niki/pkg/claim"
	httpmsg "git.gocasts.ir/ebhomengo/niki/pkg/http_msg"
	"github.com/labstack/echo/v4"
)

// Get godoc
// @Summary      Get a kind box request for a benefactor
// @Tags         Benefactors KindBoxReqs
// @Accept       json
// @Produce      json
// @Param 		 id path int true "Kind box request ID"
// @Success      200  {object}  param.KindBoxReqGetResponse
// @Failure      400  {string}  "Bad request"
// @Security 	 AuthBearerBenefactor
// @Router       /benefactors/kindboxreqs/{id} [get].
func (h Handler) Get(c echo.Context) error {
	var req param.KindBoxReqGetRequest
	if bErr := echo.PathParamsBinder(c).Uint("id", &req.KindBoxReqID).BindError(); bErr != nil {
		return echo.NewHTTPError(http.StatusBadRequest)
	}
	claims := claim.GetClaimsFromEchoContext(c)
	req.BenefactorID = claims.UserID

	resp, sErr := h.benefactorKindBoxReqSvc.Get(c.Request().Context(), req)
	if sErr != nil {
		msg, code := httpmsg.Error(sErr)
		if resp.FieldErrors != nil {
			return c.JSON(code, echo.Map{
				"message": msg,
				"errors":  resp.FieldErrors,
			})
		}

		return echo.NewHTTPError(code, msg)
	}

	return c.JSON(http.StatusOK, resp)
}
